<?php

namespace Kylin\Library;

use Illuminate\Support\ServiceProvider;

/**
 * 图书馆管理系统服务提供者
 *
 * 提供图书管理、借阅记录、读者管理等功能。
 */
class LibraryServiceProvider extends ServiceProvider
{
    /**
     * 注册服务
     */
    public function register(): void
    {
        $this->mergeConfigFrom(
            __DIR__.'/../config/kylin-library.php', 'kylin-library'
        );
    }

    /**
     * 引导服务
     */
    public function boot(): void
    {
        // 发布配置文件
        $this->publishes([
            __DIR__.'/../config/kylin-library.php' => config_path('kylin-library.php'),
        ], 'kylin-library-config');

        // 加载迁移
        $this->loadMigrationsFrom(__DIR__.'/../database/migrations');

        // 加载路由
        $this->loadRoutesFrom(__DIR__.'/../routes/api.php');
    }
}
